import numpy as np
import pandas as pd

from toarstats.metrics.interface import calculate_statistics


class TestCalculateStatistics:
    def test_calculate_statistics_simple_input(self):
        data = pd.DataFrame(
            range(10), index=pd.date_range(start="2000", periods=10, freq="H")
        )
        result = calculate_statistics("daily", "mean", data)
        expected_result = pd.DataFrame(
            {"mean": 4.5}, index=pd.DatetimeIndex(["2000"], freq="D")
        )
        pd.testing.assert_frame_equal(result, expected_result)

    def test_calculate_statistics_different_min_data_capture(self):
        data = pd.DataFrame(
            [1, 2, np.nan, 4, 5, np.nan, 7, np.nan, np.nan, np.nan],
            index=pd.date_range(start="2000", periods=10, freq="H")
        )
        result = calculate_statistics("daily", "mean", data,
                                      min_data_capture=0.75)
        expected_result = pd.DataFrame(
            {"mean": np.nan}, index=pd.DatetimeIndex(["2000"], freq="D")
        )
        pd.testing.assert_frame_equal(result, expected_result)
        data = pd.DataFrame(
            range(24),
            index=pd.date_range(start="2000", periods=24, freq="H")
        )
        result = calculate_statistics("daily", "diurnal_cycle", data)
        expected_result = pd.DataFrame(
            {"diurnal_cycle": [float(num) for num in range(24)]},
            index=pd.date_range(start="2000", periods=24, freq="H")
        )
        pd.testing.assert_frame_equal(result, expected_result)
